@@ -2,7 +2,7 @@
 The shared backbone of common ML train/test procedure for all problems
 
 Authors:
-  * Shu-wen Yang 2022
+  * Leo 2022
 """
 
 from __future__ import annotations
@@ -582,6 +582,9 @@ class Problem:
                 save_names = []
 
                 if global_step % conf.eval_step == 0:
+                    assert (
+                        valid_dataset is not None and valid_batch_sampler is not None
+                    ), f"valid dataset is not supported, please set train.eval_step to infinite"
                     logs: dict = self.evaluate(
                         evaluate,
                         "valid",
@@ -613,7 +616,10 @@ class Problem:
                         key for key in os.listdir(train_dir) if key.startswith("step_")
                     ]
                     ckpt_dirs.sort(key=lambda stem: int(stem.split("_")[-1]))
-                    if len(ckpt_dirs) >= conf.keep_num_ckpts:
+                    if (
+                        conf.keep_num_ckpts is not None
+                        and len(ckpt_dirs) >= conf.keep_num_ckpts
+                    ):
                         for ckpt_dir in ckpt_dirs[
                             : len(ckpt_dirs) - conf.keep_num_ckpts + 1
                         ]:
