@@ -3,32 +3,29 @@ The setting of Superb SID
 
 Authors
   * Po-Han Chi 2021
-  * Shu-wen Yang 2022
+  * Leo 2022
 """
 
 import logging
 import math
 import pickle
+from dataclasses import dataclass
 from pathlib import Path
-from typing import OrderedDict
+from typing import List
 
 import pandas as pd
 from omegaconf import MISSING
-from torch.utils.data import Dataset
 
 from s3prl.dataio.corpus.voxceleb1sid import VoxCeleb1SID
+from s3prl.dataio.dataset import EncodeCategory, LoadAudio
 from s3prl.dataio.encoder.category import CategoryEncoder
 from s3prl.dataio.sampler import FixedBatchSizeBatchSampler
-from s3prl.dataset.common_pipes import RandomCrop
-from s3prl.dataset.utterance_classification_pipe import UtteranceClassificationPipe
 from s3prl.nn.linear import MeanPoolingLinear
 
 from .run import Common
 
 logger = logging.getLogger(__name__)
 
-EFFECTS = [["channels", "1"], ["rate", "16000"], ["gain", "-3.0"]]
-
 
 __all__ = [
     "voxceleb1_for_sid",
@@ -99,7 +96,9 @@ class SuperbSID(Common):
             ),
             build_encoder=dict(),
             build_dataset=dict(
-                max_secs=8.0,
+                train=dict(
+                    max_secs=8.0,
+                ),
             ),
             build_batch_sampler=dict(
                 train=dict(
@@ -114,7 +113,7 @@ class SuperbSID(Common):
                 ),
             ),
             build_upstream=dict(
-                name="fbank",
+                name=MISSING,
             ),
             build_featurizer=dict(
                 layer_selections=None,
@@ -141,9 +140,9 @@ class SuperbSID(Common):
             save_task=dict(),
             train=dict(
                 total_steps=200000,
-                log_step=100,
-                eval_step=2000,
-                save_step=500,
+                log_step=500,
+                eval_step=5000,
+                save_step=1000,
                 gradient_clipping=1.0,
                 gradient_accumulate=4,
                 valid_metric="accuracy",
@@ -256,12 +255,14 @@ class SuperbSID(Common):
         Build the dataset for train/valid/test.
 
         Args:
-            build_dataset (dict): same in :obj:`default_config`
+            build_dataset (dict): same in :obj:`default_config`. with :code:`train`, :code:`valid`, :code:`test` keys, each
+                is a dictionary with the following supported options:
 
                 ====================  ====================
                 key                   description
                 ====================  ====================
                 max_secs              (float) - If a waveform is longer than :code:`max_secs` seconds, randomly crop the waveform into :code:`max_secs` seconds
+                sox_effects           (List[List[str]]) - If not None, apply sox effects on the utterance
                 ====================  ====================
 
             target_dir (str): Current experiment directory
@@ -289,51 +290,72 @@ class SuperbSID(Common):
             ====================  ====================
         """
 
-        def _superb_sid_dataset(max_secs: float):
-            data_points = OrderedDict()
-            csv = pd.read_csv(data_csv)
-            for _, row in csv.iterrows():
-                if "start_sec" in row and "end_sec" in row:
-                    start_sec = row["start_sec"]
-                    end_sec = row["end_sec"]
+        @dataclass
+        class Config:
+            train: dict = None
+            valid: dict = None
+            test: dict = None
 
-                    if math.isnan(start_sec):
-                        start_sec = None
+        conf = Config(**build_dataset)
 
-                    if math.isnan(end_sec):
-                        end_sec = None
+        assert mode in ["train", "valid", "test"]
+        if mode == "train":
+            conf = conf.train or {}
+        elif mode == "valid":
+            conf = conf.valid or {}
+        elif mode == "test":
+            conf = conf.test or {}
 
-                else:
-                    start_sec = None
-                    end_sec = None
+        @dataclass
+        class SplitConfig:
+            max_secs: float = None
+            sox_effects: List[List[str]] = None
 
-                data_points[row["id"]] = {
-                    "wav_path": row["wav_path"],
-                    "label": row["label"],
-                    "start_sec": start_sec,
-                    "end_sec": end_sec,
+        conf = SplitConfig(**conf)
+
+        csv = pd.read_csv(data_csv)
+
+        start_secs = None
+        if "start_sec" in csv.columns:
+            start_secs = csv["start_sec"].tolist()
+            start_secs = [None if math.isnan(sec) else sec for sec in start_secs]
+
+        end_secs = None
+        if "end_sec" in csv.columns:
+            end_secs = csv["end_sec"].tolist()
+            end_secs = [None if math.isnan(sec) else sec for sec in end_secs]
+
+        audio_loader = LoadAudio(
+            csv["wav_path"].tolist(),
+            start_secs,
+            end_secs,
+            max_secs=conf.max_secs,
+            sox_effects=conf.sox_effects,
+        )
+
+        with open(encoder_path, "rb") as f:
+            encoder = pickle.load(f)
+
+        label_encoder = EncodeCategory(csv["label"].tolist(), encoder)
+        ids = csv["id"].tolist()
+
+        class Dataset:
+            def __len__(self):
+                return len(ids)
+
+            def __getitem__(self, index: int):
+                audio = audio_loader[index]
+                label = label_encoder[index]
+                return {
+                    "x": audio["wav"],
+                    "x_len": audio["wav_len"],
+                    "label": label["label"],
+                    "class_id": label["class_id"],
+                    "unique_name": ids[index],
                 }
 
-            with open(encoder_path, "rb") as f:
-                encoder = pickle.load(f)
-
-            dataset = UtteranceClassificationPipe(
-                train_category_encoder=False, sox_effects=EFFECTS
-            )(
-                data_points,
-                tools={"category": encoder},
-            )
-            dataset = RandomCrop(max_secs=max_secs)(dataset)
-            dataset.update_output_keys(
-                dict(
-                    x="wav_crop",
-                    x_len="wav_crop_len",
-                )
-            )
-
-            return dataset
-
-        return _superb_sid_dataset(**build_dataset)
+        dataset = Dataset()
+        return dataset
 
     def build_batch_sampler(
         self,
@@ -342,7 +364,7 @@ class SuperbSID(Common):
         cache_dir: str,
         mode: str,
         data_csv: str,
-        dataset: Dataset,
+        dataset,
     ):
         """
         Return the batch sampler for torch DataLoader.
